//[mahjong-utils](../../../index.md)/[mahjongutils](../index.md)/[ValidationException](index.md)/[ValidationException](-validation-exception.md)

# ValidationException

[common]\
constructor(errors: [Collection](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-collection/index.html)&lt;[ErrorInfo](../-error-info/index.md)&gt;)
